@@ -1,6 +1,6 @@
 from django.core.management.base import BaseCommand, CommandError
 from django_thermostat.rules import evaluate_non_themp
-from time import localtime, strftime
+from time import localtime, strftime, sleep
 
 
 class Command(BaseCommand):
@@ -8,9 +8,9 @@ class Command(BaseCommand):
     help = 'Evaluate rules realted to heater status. The result will start or stop the heater'
 
     def handle(self, *args, **options):
+        self.stdout.write("Starting at %s" % strftime("%d.%m.%Y %H:%M:%S", localtime()))
         try:
-            self.stdout.write("Starting at %s" % strftime("%d.%m.%Y %H:%M:%S", localtime()))
             evaluate_non_themp()
-            self.stdout.write("Ended at %s" % strftime("%d.%m.%Y %H:%M:%S", localtime()))
-        except Exception, ex:
-            self.stderr.write("ERROR: %s" % ex)
+        except Exception as ex2:
+            self.sdout.write("Error ocurred: %s" % ex2)
+            
